View source: R/link_network_map.R
| link_network_map | R Documentation |
Checks which vertices of a network object can be represented with
features of a sf object.
link_network_map(m, n, m_name, n_name = "vertex.names")
m |
Object of class |
n |
Object of class |
m_name |
Name of the map field to use for the link. |
n_name |
Name of the vertex attribute to use for the link, defaults to
|
On success a list with two vectors, one of features in m
present in n, the other of nodes in n present in m,
-1 on error.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.